Test Click
open | ../tests/html/test_click_page1.html |

Click a regular link

verifyText | link | Click here for next page
clickAndWait | link |
verifyTitle | Click Page Target |
clickAndWait | previousPage |
verifyTitle | Click Page 1 |

Click a link with an enclosed image

clickAndWait | linkWithEnclosedImage |
verifyTitle | Click Page Target |
clickAndWait | previousPage |

Click an image enclosed by a link

clickAndWait | enclosedImage |
verifyTitle | Click Page Target |
clickAndWait | previousPage |

Click an image enclosed by a div enclosed by a link (SEL-451)

clickAndWait | extraEnclosedImage |
verifyTitle | Click Page Target |
clickAndWait | previousPage |

Click a link with an href anchor target within this page

click | linkToAnchorOnThisPage |
verifyTitle | Click Page 1 |
assertFailureOnNext | Timed out after 500ms |
waitForPageToLoad | 500 |
setTimeout | 30000 |

Click a link where onclick returns false

click | linkWithOnclickReturnsFalse |

Need a pause to give the page a chance to reload (so this test can fail)

pause | 300 |
verifyTitle | Click Page 1 |
setTimeout | 5000 |
open | ../tests/html/test_click_page1.html |

Try double clicking

doubleClick | doubleClickable |
assertAlert | double clicked! |